<?php 
/*
 * @package Joomla 1.5
 * @copyright Copyright (C) 2005 Open Source Matters. All rights reserved.
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
 *
 * @component XMovie Component
 * @copyright Copyright (C) Dana Harris optikool.com
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 */
defined('_JEXEC') or die ('Restricted access');
jimport('joomla.application.component.model');

/**
 * 
 * @author optikool
 * Model for the category view
 *
 */
class XMovieModelCategory extends JModel {
	var $_data = null;
	var $_pagination = null;
	var $_total = null;
	var $_query = null;
	var $_search = null;
	var $_id = null;
	var $_display = null;
	var $_cat = null;
	var $_catids = null;
	var $_catinfo = null;
	var $_pcatinfo = null;
	var $_catslug = null;
	var $_movslug = null;
	var $_component_id = null;
	
	/**
	 * Constructor function to get initial parameters
	 * @return 
	 */	 
	function __construct() {
		parent::__construct();
		
		global $mainframe, $option;
		$component = JComponentHelper::getComponent( 'com_xmovie' );
  		$cfgParams = new JParameter( $component->params );
  		$params =& $mainframe->getParams();
		$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $params->get('single_cat_mov_per_page', $cfgParams->get('cview_movs_per_page', $mainframe->getCfg('list_limit'))), 'int');
		$limitstart = JRequest::getVar('limitstart', 0, '', 'int');

		//In case limit has been changed, adjust it
		$limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);
		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);	
		
		$this->_display = $cfgParams->get('cview_sort_order');
	}

	/**
	 * Function to get the movie data from the database. 
	 * If no data is available then error view is called.	 *
	 */
	function &getData() {			
		global $mainframe, $option;
		$params =& $mainframe->getParams();
		
		if(empty($this->_data)) {			
			if($this->_id == null) {	
				$this->_id = $params->get('id', JRequest::getInt('id'));
			}
			
			$query = $this->_buildSearch();

			$this->_data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));
			$this->_total = $this->_getListCount($query);
			
			if(empty($this->_data)) {
				$this->_data = array();
			}
		}
		
		if(!empty($this->_data)) {
			$this->_cat = JRequest::getInt('id');
			MovieHelper::checkAccessLevel($this->_cat);
		}
	
		MovieHelper::checkAccessLevel($this->_id);
		$this->_getCategoryInfo();
		$this->_addToBreadcrumbs();
		
		if(!$this->_catslug) {
			$this->_catslug = MovieHelper::getCategorySlug();
		}
		
		if(!$this->_movslug) {
			$this->_movslug = MovieHelper::getMovieSlug();
		}
		
		$count = count($this->_data);
		for($i = 0; $i < $count; $i++) {
			$this->_data[$i]->slug = $this->_data[$i]->id . ':' . $this->_movslug;
			$this->_data[$i]->catslug = $this->_data[$i]->cid . ':' . $this->_catslug;
			$user =& JFactory::getUser($this->_data[$i]->submitter);
			$this->_data[$i]->submitter = $user->username;
		}
		
		$this->_component_id = $this->_getComponentID();
		
		return $this->_data;
	}
	
	function _buildSearch() {
		global $mainframe;
		$catIds = $this->_getCategories();
		$params =& $mainframe->getParams();
		$component = JComponentHelper::getComponent( 'com_xmovie' );
  		$cfgParams = new JParameter( $component->params );
		
		if (!$this->_query) {
			$search = $this->getSearch();
			$this->_query =  "SELECT DISTINCT #__xmovie_movies.id AS id, #__xmovie_movies.cid AS cid, #__xmovie_movies.name AS name,";
			$this->_query .= " #__xmovie_movies.thumb AS thumb, #__xmovie_movies.hits AS hits, #__xmovie_movies.creation_date AS creation_date,";
			$this->_query .= " #__xmovie_movies.time as time, #__xmovie_movies.quicktake AS quicktake, #__xmovie_movies.description AS description,";
			$this->_query .= " #__xmovie_movies.submitter as submitter, #__xmovie_movies.groupname AS groupname";
			$this->_query .= " FROM #__xmovie_movies, #__xmovie_categories";
			$this->_query .= " WHERE #__xmovie_movies.published = '1' AND #__xmovie_categories.published = '1'";
						
			if(count($catIds) > 0) {
				$catlist = array();
				foreach($catIds as $catId) {
					$catlist[] = " cid='{$catId}'";					
				}	
				$this->_query .= ' AND ('. implode(' OR ', $catlist).')';				
			}
						
			if ($search != '') {
				$fields = array('name', 'quicktake', 'description');

				$where = array();

				$search = $this->_db->getEscaped( $search, true );

				foreach ($fields as $field) {
					$where[] = $field . " LIKE '%{$search}%'";
				}

				$this->_query .= ' AND (' . implode(' OR ', $where).')';
			}
		}
		
		$order = $params->get('single_cat_mov_sort_order', $cfgParams->get('cview_sort_order', 'id'));
		$direction = $params->get('single_cat_mov_sort_order_dir', $cfgParams->get('cview_sort_order_dir', 'asc'));
		
		if($order == 'ordering') {
			$this->_query .= " ORDER BY ordering {$direction}";
		} else {
			$this->_query .=  " ORDER BY {$order} {$direction}";
		}
				
		return $this->_query;
	}
	
	/**
	 * Function to return an array of sub category ids in the current category.
	 * 
	 * @return catids The array of category ids.
	 */
	function getCategories() {
		if(empty($this->_catids)) {
			return $this->_getCategories();
		} 
		return $this->_catids;
	}
	
	/**
	 *  Function to get all sub cagegories in the current categories that is allowed for the 
	 *  visitors access level.
	 *  
	 *  @return catids The sub category ids
	 */
	function _getCategories() {
		$catids = array();
		$rows = array();
		$access = MovieHelper::getAccessLevel();

		if(empty($this->_catids)) {
			if($this->_id == null) {
				$this->_id = JRequest::getInt('id');
			}
			$catids[] = $this->_id;
			$query = "SELECT id FROM #__xmovie_categories WHERE published = '1' AND pid= '{$this->_id}'".$access;
			$db =& JFactory::getDBO();
			$db->setQuery($query);
			$rows = $db->loadResultArray();

			while(count($rows) > 0) {
				$catArray = array();				
				
				foreach($rows as $row) {
					$catids[] = $row;
					$catArray[] = " pid='{$row}'";					
				}
				
				$query = "SELECT id FROM #__xmovie_categories WHERE published = '1'";
				if(count($catArray) > 0) {
					$query .= ' AND ('. implode(' OR ', $catArray).')';
				}
				$query .= $access;
				$db->setQuery($query);
				$rows = array();
				$rows = $db->loadResultArray();	
		
			}
			
		} 	
		
		$this->_catids = $catids;
		return $this->_catids;
	}
	
	function getCatName($cat = '') {
		if ($cat == '') {
			$cat = $this->_cat;
		}

		$query = "SELECT id, name, pid FROM #__xmovie_categories WHERE published = '1' AND id ='{$cat}' LIMIT 1";
		$row = $this->_getList($query);

		return $row;
	}
	
	/**
	 * Function to add current id name to the breadcrumbs. This function also checks
	 * if the current category has a parent category and if so adds that too. 
	 * 
	 */
	function _addToBreadcrumbs() {
		global $mainframe;
		jimport('joomla.environment.uri');		
		$com = JComponentHelper::getComponent('com_xmovie');
		$db =& JFactory::getDBO();		
		$query = "SELECT id, name, link FROM #__menu WHERE published = '1' AND componentid='{$com->id}' AND link LIKE '%main%'";		
		$db->setQuery($query);
		$main = $db->loadRow();		
		$menu = $this->_getMenuItems();
		$pathway = &$mainframe->getPathway();
		$catalias = MovieHelper::getCategorySlug();
		
		$currid = MovieHelper::getComponentId();
		
		if($currid->id == $this->getComponentID()) {
			if(isset($main)) {
				unset($pathway->_pathway);
				$pathway->addItem($main[1], JRoute::_($main[2].'&amp;Itemid='.$main[0]));		
			}
			
			$breadcrumbs = $pathway->getPathway();
			
			if(count($breadcrumbs) > 0) {
				$count = count($breadcrumbs) - 1;
	
				$currURI =& JURI::getInstance($breadcrumbs[$count]->link);
				$itemid = $currURI->getVar('Itemid');
			
				if(!$itemid) {
					if(isset($main)) {
						$itemid = $main[0];
					}
				}
		
				if(isset($this->_data[0]) && $this->_data[0]->cid != 1) {					
					$catName = $this->getCatName();
						
					if ($catName[0]->pid != 1) {
						$catPreName = $this->getCatName($catName[0]->pid);
						$link = JRoute::_('index.php?option=com_xmovie&view=category&id='.$catPreName[0]->id.':'.$catalias.'&Itemid='.$itemid);
						$pathway->addItem($catPreName[0]->name, $link);
					}
	
					if(strtolower($catName[0]->name) != strtolower($pathway->_pathway[0]->name)) {
						$link = JRoute::_('index.php?option=com_xmovie&view=category&id='.$catName[0]->id.':'.$catalias.'&Itemid='.$itemid);
						$pathway->addItem($catName[0]->name, $link);
					}
				}
			}
		} else {
			$itemid = JRequest::getInt('Itemid');
			
			if(isset($this->_data[0]) && $this->_data[0]->cid != 1) {					
				$catName = $this->getCatName();
						
				if ($catName[0]->pid != 1) {
					$catPreName = $this->getCatName($catName[0]->pid);
					$link = JRoute::_('index.php?option=com_xmovie&view=category&id='.$catPreName[0]->id.':'.$catalias.'&Itemid='.$itemid);
					$pathway->addItem($catPreName[0]->name, $link);
				}
	
				if(strtolower($catName[0]->name) != strtolower($pathway->_pathway[0]->name)) {
					$link = JRoute::_('index.php?option=com_xmovie&view=category&id='.$catName[0]->id.':'.$catalias.'&Itemid='.$itemid);
					$pathway->addItem($catName[0]->name, $link);
				}
			}
		}				
	}
		
	function _getMenuItems() {
		jimport('joomla.environment.uri');
		$com = JComponentHelper::getComponent('com_xmovie');

		$query = "SELECT id, link, parent FROM #__menu WHERE published = '1' AND componentid='{$com->id}' AND sublevel != '0'";		
		$links = $this->_getList($query);
		$where = array();

		if(count($links) > 0) {
			foreach($links as $link) {				
				$currURI = JURI::getInstance($link->link);
				if($currURI->getVar('id') == $this->_id) {					
					return $link->id;
				}
			}
		}
		
		return $where;
	}
	
	/**
	 * Function to return information for the current category.
	 *
	 * @return _catinfo An array of field values for the current category id. 
	 */
	function _getCategoryInfo() {
		if(!$this->_catinfo) {
			$category =& JTable::getInstance('category', 'Table');
			$category->load($this->_id);
			$category->hit($this->_id);
		
			MovieHelper::checkAccessLevel( $category->id );
			MovieHelper::checkAccessLevel( $category->pid );

			$this->_catinfo = $category;
		}
		
		return $this->_catinfo;
	}
	
	/**
	 * Function to return information for the primary category of the current category.
	 *
	 * @return _catinfo An array of field values for the current category id. 
	 */
	function _getPrimaryCatInfo() {
		if(!$this->_pcatinfo) {
			$category =& JTable::getInstance('category', 'Table');
			$category->load($this->_catinfo->pid);
			
			MovieHelper::checkAccessLevel( $category->id );
			MovieHelper::checkAccessLevel( $category->pid );
			
			$this->_pcatinfo = $category;
		}
		return $this->_pcatinfo;
	}
	
	/**
	 * Function to get sub categories in the current category.
	 *
	 *	@return $rows Sub Categories found.
	 */
	function getSubCategories() {
		global $mainframe;
		$params =& $mainframe->getParams();
		$component = JComponentHelper::getComponent( 'com_xmovie' );
  		$cfgParams = new JParameter( $component->params );
		$access = MovieHelper::getAccessLevel();
		$query = "SELECT * FROM #__xmovie_categories WHERE published = '1' AND pid='{$this->_id}'";
		$query .= $access;
		$order = $params->get('single_cat_sort_order', $cfgParams->get('cview_cat_sort_order', 'id'));
		$direction = $params->get('single_cat_sort_order_dir', $cfgParams->get('cview_cat_sort_order_dir', 'asc'));
		
		if($order == 'ordering') {
			$query .= " ORDER BY ordering {$direction}";
		} else {
			$query .=  " ORDER BY {$order} {$direction}";
		}

		if($params->get('single_cat_limit', $cfgParams->get('cview_cat_limit', 0)) != 0) {
			$query .= " LIMIT ".$params->get('single_cat_limit', $cfgParams->get('cview_cat_limit', 8));
		}
			
		$rows = $this->_getList($query);
		
		
		
		$count = count($rows);
		for($i = 0; $i < $count; $i++) {
			$rows[$i]->slug = $rows[$i]->id . ':' . $this->_movslug;
			$rows[$i]->catslug = $rows[$i]->pid . ':' . $this->_catslug;
		}

		return $rows;
	}
	
	function getPagination() {
		if(!$this->_pagination) {
			jimport('joomla.html.pagination');
			global $mainframe;
			$this->_pagination = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit'));
		}

		return $this->_pagination;
	}
	
	function getCategoryInfo() {
		return $this->_catinfo;
	}
	
	function getSearch() {
		if (!$this->_search) {
			global $mainframe, $option;

			$search = $mainframe->getUserStateFromRequest( "$option.search", 'search', '', 'string' );
			$this->_search = JString::strtolower($search);
		}

		return $this->_search;
	}
	
	function getTotal() {
		if (!$this->_total) {
			$this->_total = 0;
		}
		return $this->_total;
	}
	
	function getComponentID() {
		return $this->_component_id;
	}
	
	function _getComponentID() {
		$com = JComponentHelper::getComponent('com_xmovie');

		$db =& JFactory::getDBO();		
		$query = "SELECT id FROM #__menu WHERE published = '1' AND componentid='{$com->id}'";		
		$db->setQuery($query);
		$id = $db->loadResult();
		
		return $id;
	}
	
}
?>