<?php 
/*
 * @package Joomla 1.5
 * @copyright Copyright (C) 2005 Open Source Matters. All rights reserved.
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
 *
 * @component XMovie Component
 * @copyright Copyright (C) Dana Harris optikool.com
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 */
defined('_JEXEC') or die ('Restricted access');
jimport('joomla.application.component.model');

/**
 * 
 * @author dharris
 * Model for the main view
 *
 */
class XMovieModelMain extends JModel {
	var $_data = null;
	var $_pagination = null;
	var $_total = null;
	var $_query = null;
	var $_search = null;
	var $_id = null;
	var $_display = null;
	var $_catslug = null;
	var $_movslug = null;
	var $_cat = null;
	
	/**
	 * Constructor function to get initial parameters
	 * @return 
	 */	 
	function __construct() {
		parent::__construct();
		
		global $mainframe, $option;
		$params =& $mainframe->getParams();
		
		$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $params->get('mov_per_page', $mainframe->getCfg('list_limit')), 'int');
		$limitstart = JRequest::getVar('limitstart', 0, '', 'int');
		
		//In case limit has been changed, adjust it
		$limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);
		
		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
		
		
		$this->_display = $params->get('sort_order');
	}

	/**
	 * Function to get the movie data from the database. 
	 * If no data is available then error view is called.	 *
	 */
	function &getData() {			
		global $option;
		
		if(empty($this->_data)) {			
			$this->_id = JRequest::getInt('id');
			$query = $this->_buildSearch();

			$this->_data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));
			$this->_total = $this->_getListCount($query);

			if(empty($this->_data)) {
				$this->_data = array();
			}
		}
		
		if(!$this->_catslug) {
			$this->_catslug = MovieHelper::getCategorySlug();
		}
		
		if(!$this->_movslug) {
			$this->_movslug = MovieHelper::getMovieSlug();
		}
		
		$count = count($this->_data);
		for($i = 0; $i < $count; $i++) {
			$this->_data[$i]->slug = $this->_data[$i]->id . ':' . $this->_movslug;
			$this->_data[$i]->catslug = $this->_data[$i]->cid . ':' . $this->_catslug;
			$user =& JFactory::getUser($this->_data[$i]->submitter);
			$this->_data[$i]->submitter = $user->username;
		}

		return $this->_data;
	}
	
	function getBreadcrumbs() {
		global $mainframe;
		jimport('joomla.environment.uri');
		$com = JComponentHelper::getComponent('com_xmovie');
		$db =& JFactory::getDBO();		
		$query = "SELECT id, name, link FROM #__menu WHERE published = '1' AND componentid='{$com->id}' AND link LIKE '%main%'";		
		$db->setQuery($query);
		$main = $db->loadRow();
		
		$menu = $this->_getMenuItems();
		$pathway = &$mainframe->getPathway();
		unset($pathway->_pathway);
		$pathway->addItem($main[1], JRoute::_($main[2].'&amp;Itemid='.$main[0]));		
		
		$breadcrumbs = $pathway->getPathway();
				
		if(count($breadcrumbs) > 0) {
			$count = count($breadcrumbs) - 1;
	
			$currURI =& JURI::getInstance($breadcrumbs[$count]->link);
			$itemid = $currURI->getVar('Itemid');
		}
	}

	/**
	 * Function to get information for a particular category from the database. If cdata comes back 
	 * empty, the visitor didn't have access or the category was unpublished.
	 * 
	 * @return $cdata Category array of information.
	 */
	function getCategory() {
		global $option, $mainframe;
		$params =& $mainframe->getParams();
		$component = JComponentHelper::getComponent( 'com_xmovie' );
  		$cfgParams = new JParameter( $component->params );
  		
		$access = MovieHelper::getAccessLevel();
		$query = "SELECT * FROM #__xmovie_categories WHERE published = '1' AND id ='{$this->_id}'".$access." LIMIT 1";
		$cdata = $this->_getList($query);
		if(empty($cdata)) {
			JError::raiseError('404', JText::_('CATEGORY NOT FOUND'));
		}
		return $cdata;
	}
	
	function getSubCategories() {
		global $option, $mainframe;
		$params =& $mainframe->getParams();
		$component = JComponentHelper::getComponent( 'com_xmovie' );
  		$cfgParams = new JParameter( $component->params );
		$where = $this->_getMenuSubCategories();
		$access = MovieHelper::getAccessLevel();
		$query = "SELECT * FROM #__xmovie_categories WHERE published = '1'";
		if(count($where) > 0) {
			$query .= ' AND ('. implode(' OR ', $where).')';
			$query .= " AND id != '1'";
			$query .= $access;
			
			$order = $cfgParams->get('cview_cat_sort_order', 'id');
			$direction = $cfgParams->get('cview_cat_sort_order_dir', 'asc');
		
			if($order == 'ordering') {
				$query .= " ORDER BY ordering {$direction}";
			} else {
				$query .=  " ORDER BY {$order} {$direction}";
			}
			
			if($params->get('cat_limit') != 0) {
				$query .= " LIMIT ".$params->get('cat_limit', 8);
			}
				
			$rows = $this->_getList($query);
		} else {
			$rows = array();
		}

		$count = count($rows);
		
		if(!$this->_catslug) {
			$this->_catslug = MovieHelper::getCategorySlug();
		}
		
		for($i = 0; $i < $count; $i++) {
			$rows[$i]->slug = $rows[$i]->id . ':' . $this->_catslug;								
		}
		
		return $rows;
	}
	
	function _getMenuCategories() {
		jimport('joomla.environment.uri');
		$com = JComponentHelper::getComponent('com_xmovie');
		$access = MovieHelper::getAccessLevel();
		$query = "SELECT link FROM #__menu WHERE published = '1' AND componentid='{$com->id}'".$access;
		$links = $this->_getList($query);

		$where = array();
		if(count($links) > 0) {
			$where[] = " cid = '1'";
			$cid = '';
			foreach($links as $link) {
				$currURI = JURI::getInstance($link->link);
				$cid = $currURI->getVar('id');
				if(!empty($cid)) {
					$where[] = " cid = '{$currURI->getVar('id')}'";
				}
			}
		}
		
		return $where;
	}
	
	function _getMenuSubCategories() {
		jimport('joomla.environment.uri');
		$com = JComponentHelper::getComponent('com_xmovie');
		$access = MovieHelper::getAccessLevel();
		$query = "SELECT link FROM #__menu WHERE published = '1' AND componentid='{$com->id}'".$access;
		$links = $this->_getList($query);

		$where = array();
		if(count($links) > 0) {
			$where[] = "pid = '1'";
			$cid = '';
			foreach($links as $link) {
				$currURI = JURI::getInstance($link->link);
				$cid = $currURI->getVar('id');
				if(!empty($cid)) {
					$where[] = "pid = '{$currURI->getVar('id')}'";
				}
			}
		}
		
		return $where;
	}
	
	function _getMenuItems() {
		jimport('joomla.environment.uri');
		$com = JComponentHelper::getComponent('com_xmovie');

		$query = "SELECT id, link, parent FROM #__menu WHERE published = '1' AND componentid='{$com->id}' AND sublevel != '0'";		
		$links = $this->_getList($query);
		$where = array();

		if(count($links) > 0) {
			foreach($links as $link) {				
				$currURI = JURI::getInstance($link->link);
				if($currURI->getVar('id') == $this->_cat) {					
					return $link->id;
				}
			}
		}
		
		return $where;
	}
	
	function _buildSearch() {
		global $mainframe;
		$display = $this->_display;
		$idList = $this->_getMenuCategories();
		if (!$this->_query) {
			$search = $this->getSearch();
			$this->_query =  "SELECT #__xmovie_movies.id AS id, #__xmovie_movies.cid AS cid, #__xmovie_movies.name AS name,";
			$this->_query .= " #__xmovie_movies.thumb AS thumb, #__xmovie_movies.hits AS hits, #__xmovie_movies.creation_date AS creation_date,";
			$this->_query .= " #__xmovie_movies.time as time, #__xmovie_movies.quicktake AS quicktake, #__xmovie_movies.description AS description,";
			$this->_query .= " #__xmovie_movies.submitter as submitter, #__xmovie_movies.groupname AS groupname";
			$this->_query .= " FROM #__xmovie_movies, #__xmovie_categories";
			$this->_query .= " WHERE #__xmovie_movies.published = '1' AND #__xmovie_categories.published = '1'";
			$this->_query .= " AND #__xmovie_movies.cid = #__xmovie_categories.id";		
			
			if ($search != '') {
				$fields = array('name', 'quicktake', 'description');

				$where = array();

				$search = $this->_db->getEscaped( $search, true );

				foreach ($fields as $field) {
					$where[] = $field . " LIKE '%{$search}%'";
				}

				$this->_query .= ' AND (' . implode(' OR ', $where).')';
			}
			
			$this->_query .= MovieHelper::getAccessLevelCC();
		}
		
		switch($display) {				
			case 'random':
				$this->_query .= " ORDER BY RAND()";
				break;
			case 'popular':
				$this->_query .= " ORDER BY hits DESC";
				break;
			case 'latest':
			default:
				$this->_query .= " ORDER BY creation_date DESC";	
				break;					
		}
		
		return $this->_query;
	}
	
	function getMainInfo() {
		$query = "SELECT * FROM #__xmovie_categories WHERE id = '1'";
		$row = $this->_getList($query);
		return $row[0];
	}
	
	function getTotal() {
		if (!$this->_total) {
			$this->_total = 0;
		}
		return $this->_total;
	}
	
	function getPagination() {
		if(!$this->_pagination) {
			jimport('joomla.html.pagination');
			global $mainframe;
			$this->_pagination = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit'));
		}

		return $this->_pagination;
	}
	
	function getSearch()
	{
		if (!$this->_search) {
			global $mainframe, $option;

			$search = $mainframe->getUserStateFromRequest( "$option.search", 'search', '', 'string' );
			$this->_search = JString::strtolower($search);
		}

		return $this->_search;
	}
}
?>

